package Apache::Ocsinventory::Server::Capacities::CernExtension;

use strict;

# This block specify which wrapper will be used ( your module will be compliant with all mod_perl versions )
BEGIN{
  if($ENV{'OCS_MODPERL_VERSION'} == 1){
    require Apache::Ocsinventory::Server::Modperl1;
    Apache::Ocsinventory::Server::Modperl1->import();
  }elsif($ENV{'OCS_MODPERL_VERSION'} == 2){
    require Apache::Ocsinventory::Server::Modperl2;
    Apache::Ocsinventory::Server::Modperl2->import();
  }
}

# These are the core modules you must include in addition
use Apache::Ocsinventory::Server::System;
use Apache::Ocsinventory::Server::Communication;
use Apache::Ocsinventory::Server::Constants;

# Initialize option
push @{$Apache::Ocsinventory::OPTIONS_STRUCTURE},{
  'NAME' => 'CERNEXTENSION',
  'HANDLER_PROLOG_READ' => undef,
  'HANDLER_PROLOG_RESP' => undef,
  'HANDLER_PRE_INVENTORY' => \&cernextension_pre_inventory,
  'HANDLER_POST_INVENTORY' => undef,
  'REQUEST_NAME' => undef,
  'HANDLER_REQUEST' => undef,
  'HANDLER_DUPLICATE' => undef,
  'TYPE' => OPTION_TYPE_SYNC,
  'XML_PARSER_OPT' => {
      'ForceArray' => []
  }
};


sub getLocationFromLdap{
    my $hostname = shift;
    my $ldapServer = 'xldap.cern.ch';
    my $ldapBinary = '/usr/bin/ldapsearch';
    my $reply = "";
    if ( !-x  $ldapBinary ){
	return $reply;
    }
    my $ldapCommand = "$ldapBinary -x -h $ldapServer -b dc=cern,dc=ch \"(&(objectClass=computer)(distinguishedName=CN=$hostname,OU=CERN Linux Computers,DC=cern,DC=ch))\" location";
    $reply = `$ldapCommand|grep "^location"`;
    chomp $reply;
    $reply =~ s/^location: //;
    return $reply;
}


# return computer location
sub getLocation {
	my $xml = shift;
	my $clientHostName = $xml->{'CONTENT'}->{'HARDWARE'}->{'NAME'};
	my $location = getLocationFromLdap($clientHostName);
	
	if ($location eq '1') {
		$location = "";
	}
	return $location;
}

sub cernextension_pre_inventory {

  my $current_context = shift;
  my $xml = $current_context->{'XML_ENTRY'};
  
  my $loc = $xml->{'CONTENT'}->{'CERNEXTENSION'}->{'LOCATION'};
  
  if ($loc eq '' or $loc eq 'unknown') {
	my $tmp = getLocation($xml);
	&_log(0,'cernextension',"Location not found by client! Server found: ".$tmp);
	$xml->{'CONTENT'}->{'CERNEXTENSION'}->{'LOCATION'} = $tmp;
  } 
  
  return INVENTORY_CONTINUE;
}

1;

